@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _OPTIONS_H_
-#define _OPTIONS_H_
+#ifndef OPTIONS_H
+#define OPTIONS_H
 
 #include <string>
 #include "ColorTable.h"
@@ -400,6 +400,7 @@ double opt_geometry_occ_sew_faces(OPT_ARGS_NUM);
 double opt_geometry_occ_parallel(OPT_ARGS_NUM);
 double opt_geometry_occ_boolean_preserve_numbering(OPT_ARGS_NUM);
 double opt_geometry_occ_scaling(OPT_ARGS_NUM);
+double opt_geometry_occ_import_labels(OPT_ARGS_NUM);
 double opt_geometry_old_circle(OPT_ARGS_NUM);
 double opt_geometry_old_newreg(OPT_ARGS_NUM);
 double opt_geometry_old_ruled_surface(OPT_ARGS_NUM);
@@ -475,6 +476,7 @@ double opt_mesh_file_format(OPT_ARGS_NUM);
 double opt_mesh_newton_convergence_test_xyz(OPT_ARGS_NUM);
 double opt_mesh_msh_file_version(OPT_ARGS_NUM);
 double opt_mesh_med_file_minor_version(OPT_ARGS_NUM);
+double opt_mesh_med_import_groups_of_nodes(OPT_ARGS_NUM);
 double opt_mesh_partition_split_mesh_files(OPT_ARGS_NUM);
 double opt_mesh_partition_save_topology_file(OPT_ARGS_NUM);
 double opt_mesh_partition_num(OPT_ARGS_NUM);
@@ -497,19 +499,18 @@ double opt_mesh_binary(OPT_ARGS_NUM);
 double opt_mesh_smooth_cross_field(OPT_ARGS_NUM);
 double opt_mesh_cross_field_closest_point(OPT_ARGS_NUM);
 double opt_mesh_bdf_field_format(OPT_ARGS_NUM);
+double opt_mesh_stl_remove_duplicate_triangles(OPT_ARGS_NUM);
 double opt_mesh_boundary_layer_fan_points(OPT_ARGS_NUM);
 double opt_mesh_nb_smoothing(OPT_ARGS_NUM);
 double opt_mesh_algo2d(OPT_ARGS_NUM);
 double opt_mesh_algo3d(OPT_ARGS_NUM);
 double opt_mesh_algo_recombine(OPT_ARGS_NUM);
 double opt_mesh_recombine_all(OPT_ARGS_NUM);
+double opt_mesh_recombine_optimize_topology(OPT_ARGS_NUM);
 double opt_mesh_recombine3d_all(OPT_ARGS_NUM);
 double opt_mesh_recombine3d_level(OPT_ARGS_NUM);
 double opt_mesh_recombine3d_conformity(OPT_ARGS_NUM);
 double opt_mesh_flexible_transfinite(OPT_ARGS_NUM);
-double opt_mesh_do_recombination_test(OPT_ARGS_NUM);
-double opt_mesh_recombination_test_start(OPT_ARGS_NUM);
-double opt_mesh_recombination_no_greedy_strat(OPT_ARGS_NUM);
 double opt_mesh_algo_subdivide(OPT_ARGS_NUM);
 double opt_mesh_mesh_only_visible(OPT_ARGS_NUM);
 double opt_mesh_min_circ_points(OPT_ARGS_NUM);
@@ -522,7 +523,9 @@ double opt_mesh_ho_nlayers(OPT_ARGS_NUM);
 double opt_mesh_ho_threshold_min(OPT_ARGS_NUM);
 double opt_mesh_ho_threshold_max(OPT_ARGS_NUM);
 double opt_mesh_ho_poisson(OPT_ARGS_NUM);
-double opt_mesh_ho_opt_prim_surf_mesh(OPT_ARGS_NUM);
+double opt_mesh_ho_prim_surf_mesh(OPT_ARGS_NUM);
+double opt_mesh_ho_iter_max(OPT_ARGS_NUM);
+double opt_mesh_ho_pass_max(OPT_ARGS_NUM);
 double opt_mesh_second_order_experimental(OPT_ARGS_NUM);
 double opt_mesh_second_order_linear(OPT_ARGS_NUM);
 double opt_mesh_second_order_incomplete(OPT_ARGS_NUM);
@@ -556,6 +559,7 @@ double opt_mesh_max_num_threads_2d(OPT_ARGS_NUM);
 double opt_mesh_max_num_threads_3d(OPT_ARGS_NUM);
 double opt_mesh_angle_tolerance_facet_overlap(OPT_ARGS_NUM);
 double opt_mesh_renumber(OPT_ARGS_NUM);
+double opt_mesh_unv_strict_format(OPT_ARGS_NUM);
 double opt_solver_listen(OPT_ARGS_NUM);
 double opt_solver_timeout(OPT_ARGS_NUM);
 double opt_solver_plugins(OPT_ARGS_NUM);
