@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributor(s):
 //   Jonathan Lambrechts
@@ -208,7 +208,7 @@ void fieldWindow::loadFieldViewList()
   put_on_view_btn->clear();
   put_on_view_btn->add("Create new view");
   put_on_view_btn->activate();
-  for(unsigned int i = 0; i < PView::list.size(); i++) {
+  for(std::size_t i = 0; i < PView::list.size(); i++) {
     std::ostringstream s;
     s << "Put on View [" << i << "]";
     put_on_view_btn->add(s.str().c_str());
