@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributor(s):
 //   Stephen Guzik
@@ -109,8 +109,9 @@ int fileChooser(FILE_CHOOSER_TYPE type, const char *message, const char *filter,
   static int thefilterindex = 0;
 
   // reset the filter and the selection if the filter has changed
-  if(strncmp(thefilter, filter, 1024)) {
-    strncpy(thefilter, filter, 1024);
+  if(strncmp(thefilter, filter, sizeof(thefilter) - 1)) {
+    strncpy(thefilter, filter, sizeof(thefilter) - 1);
+    thefilter[sizeof(thefilter) - 1] = '\0';
     thefilterindex = 0;
   }
 
@@ -1143,7 +1144,7 @@ int mshFileDialog(const char *name)
           0, GMSH_SET | GMSH_GUI,
           (dialog->c->value() == 0) ?
             1.0 :
-            (dialog->c->value() == 1 || dialog->c->value() == 2) ? 2.2 : 4.0);
+            (dialog->c->value() == 1 || dialog->c->value() == 2) ? 2.2 : 4.1);
         opt_mesh_binary(
           0, GMSH_SET | GMSH_GUI,
           (dialog->c->value() == 2 || dialog->c->value() == 4) ? 1 : 0);
@@ -1523,12 +1524,12 @@ static void _saveViews(const std::string &name, int which, int format,
   }
   else if(which == 1) {
     int numVisible = 0;
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(PView::list[i]->getOptions()->visible) numVisible++;
     if(!numVisible) { Msg::Error("No visible view"); }
     else {
       bool first = true;
-      for(unsigned int i = 0; i < PView::list.size(); i++) {
+      for(std::size_t i = 0; i < PView::list.size(); i++) {
         if(PView::list[i]->getOptions()->visible) {
           std::string fileName = name;
           if(!canAppend && numVisible > 1) {
@@ -1543,7 +1544,7 @@ static void _saveViews(const std::string &name, int which, int format,
     }
   }
   else {
-    for(unsigned int i = 0; i < PView::list.size(); i++) {
+    for(std::size_t i = 0; i < PView::list.size(); i++) {
       std::string fileName = name;
       if(!canAppend && PView::list.size() > 1) {
         std::ostringstream os;
@@ -1639,12 +1640,12 @@ static void _saveAdaptedViews(const std::string &name, int useDefaultName,
   }
   else if(which == 1) {
     int numVisible = 0;
-    for(unsigned int i = 0; i < PView::list.size(); i++)
+    for(std::size_t i = 0; i < PView::list.size(); i++)
       if(PView::list[i]->getOptions()->visible) numVisible++;
     if(!numVisible) { Msg::Error("No visible view"); }
     else {
       bool first = true;
-      for(unsigned int i = 0; i < PView::list.size(); i++) {
+      for(std::size_t i = 0; i < PView::list.size(); i++) {
         if(PView::list[i]->getOptions()->visible) {
           std::string fileName = name;
           if(!canAppend && numVisible > 1) {
@@ -1661,7 +1662,7 @@ static void _saveAdaptedViews(const std::string &name, int useDefaultName,
     }
   }
   else {
-    for(unsigned int i = 0; i < PView::list.size(); i++) {
+    for(std::size_t i = 0; i < PView::list.size(); i++) {
       std::string fileName = name;
       if(!canAppend && PView::list.size() > 1) {
         std::ostringstream os;
