@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <sstream>
 #include "GmshConfig.h"
@@ -39,7 +39,7 @@ GFace::GFace(GModel *model, int tag)
 {
   meshStatistics.status = GFace::PENDING;
   meshStatistics.refineAllEdges = false;
-  resetMeshAttributes();
+  GFace::resetMeshAttributes();
 }
 
 GFace::~GFace()
@@ -52,7 +52,7 @@ GFace::~GFace()
 
   if(va_geom_triangles) delete va_geom_triangles;
 
-  deleteMesh();
+  GFace::deleteMesh();
 }
 
 int GFace::getCurvatureControlParameter() const
@@ -148,16 +148,16 @@ int GFace::delEdge(GEdge *edge)
 void GFace::deleteMesh(bool onlyDeleteElements)
 {
   if(!onlyDeleteElements) {
-    for(unsigned int i = 0; i < mesh_vertices.size(); i++)
+    for(std::size_t i = 0; i < mesh_vertices.size(); i++)
       delete mesh_vertices[i];
     mesh_vertices.clear();
     transfinite_vertices.clear();
   }
-  for(unsigned int i = 0; i < triangles.size(); i++) delete triangles[i];
+  for(std::size_t i = 0; i < triangles.size(); i++) delete triangles[i];
   triangles.clear();
-  for(unsigned int i = 0; i < quadrangles.size(); i++) delete quadrangles[i];
+  for(std::size_t i = 0; i < quadrangles.size(); i++) delete quadrangles[i];
   quadrangles.clear();
-  for(unsigned int i = 0; i < polygons.size(); i++) delete polygons[i];
+  for(std::size_t i = 0; i < polygons.size(); i++) delete polygons[i];
   polygons.clear();
   deleteVertexArrays();
   model()->destroyMeshCaches();
@@ -168,7 +168,7 @@ std::size_t GFace::getNumMeshElements() const
   return triangles.size() + quadrangles.size() + polygons.size();
 }
 
-unsigned int GFace::getNumMeshElementsByType(const int familyType) const
+std::size_t GFace::getNumMeshElementsByType(const int familyType) const
 {
   if(familyType == TYPE_TRI)
     return triangles.size();
@@ -180,10 +180,10 @@ unsigned int GFace::getNumMeshElementsByType(const int familyType) const
   return 0;
 }
 
-unsigned int GFace::getNumMeshParentElements()
+std::size_t GFace::getNumMeshParentElements()
 {
-  unsigned int n = 0;
-  for(unsigned int i = 0; i < polygons.size(); i++)
+  std::size_t n = 0;
+  for(std::size_t i = 0; i < polygons.size(); i++)
     if(polygons[i]->ownsParent()) n++;
   return n;
 }
@@ -211,7 +211,7 @@ MElement *const *GFace::getStartElementType(int type) const
   return 0;
 }
 
-MElement *GFace::getMeshElement(unsigned int index) const
+MElement *GFace::getMeshElement(std::size_t index) const
 {
   if(index < triangles.size())
     return triangles[index];
@@ -223,7 +223,7 @@ MElement *GFace::getMeshElement(unsigned int index) const
 }
 
 MElement *GFace::getMeshElementByType(const int familyType,
-                                      const unsigned int index) const
+                                      const std::size_t index) const
 {
   if(familyType == TYPE_TRI)
     return triangles[index];
@@ -258,8 +258,8 @@ SBoundingBox3d GFace::bounds(bool fast) const
   else {
     int ipp = getNumMeshElements() / 20;
     if(ipp < 1) ipp = 1;
-    for(unsigned int i = 0; i < getNumMeshElements(); i += ipp)
-      for(unsigned int j = 0; j < getMeshElement(i)->getNumVertices(); j++)
+    for(std::size_t i = 0; i < getNumMeshElements(); i += ipp)
+      for(std::size_t j = 0; j < getMeshElement(i)->getNumVertices(); j++)
         res += getMeshElement(i)->getVertex(j)->point();
   }
   return res;
@@ -284,12 +284,18 @@ SOrientedBoundingBox GFace::getOBB()
           vertices.push_back(mv->point());
         }
         // Don't forget to add the first and last vertices...
-        SPoint3 pt1((*ed)->getBeginVertex()->x(), (*ed)->getBeginVertex()->y(),
-                    (*ed)->getBeginVertex()->z());
-        SPoint3 pt2((*ed)->getEndVertex()->x(), (*ed)->getEndVertex()->y(),
-                    (*ed)->getEndVertex()->z());
-        vertices.push_back(pt1);
-        vertices.push_back(pt2);
+        if((*ed)->getBeginVertex()){
+          SPoint3 pt1((*ed)->getBeginVertex()->x(),
+                      (*ed)->getBeginVertex()->y(),
+                      (*ed)->getBeginVertex()->z());
+          vertices.push_back(pt1);
+        }
+        if((*ed)->getEndVertex()){
+          SPoint3 pt2((*ed)->getEndVertex()->x(),
+                      (*ed)->getEndVertex()->y(),
+                      (*ed)->getEndVertex()->z());
+          vertices.push_back(pt2);
+        }
       }
     }
     else if(buildSTLTriangulation()) {
@@ -450,7 +456,7 @@ void GFace::writeGEO(FILE *fp)
         it++)
       ori.push_back((*it) > 0 ? 1 : -1);
     fprintf(fp, "Line Loop(%d) = ", tag());
-    for(unsigned int i = 0; i < num.size(); i++) {
+    for(std::size_t i = 0; i < num.size(); i++) {
       if(i)
         fprintf(fp, ", %d", num[i] * ori[i]);
       else
@@ -480,7 +486,7 @@ void GFace::writeGEO(FILE *fp)
     fprintf(fp, "Transfinite Surface {%d}", tag());
     if(meshAttributes.corners.size()) {
       fprintf(fp, " = {");
-      for(unsigned int i = 0; i < meshAttributes.corners.size(); i++) {
+      for(std::size_t i = 0; i < meshAttributes.corners.size(); i++) {
         if(i) fprintf(fp, ",");
         fprintf(fp, "%d", meshAttributes.corners[i]->tag());
       }
@@ -524,7 +530,7 @@ void GFace::computeMeanPlane()
     double res[4] = {0., 0., 0., 0.}, xm = 0., ym = 0., zm = 0.;
     if(pts.size() >= 3) {
       SVector3 d01(pts[0], pts[1]);
-      for(unsigned int i = 2; i < pts.size(); i++) {
+      for(std::size_t i = 2; i < pts.size(); i++) {
         SVector3 d0i(pts[0], pts[i]);
         SVector3 n = crossprod(d01, d0i);
         // if too small, the points are almost colinear; tolerance is relatively
@@ -583,7 +589,7 @@ void GFace::computeMeanPlane()
         ite != edg.end(); ite++) {
       const GEdge *e = *ite;
       if(e->mesh_vertices.size() > 1) {
-        for(unsigned int i = 0; i < e->mesh_vertices.size(); i++)
+        for(std::size_t i = 0; i < e->mesh_vertices.size(); i++)
           pts.push_back(e->mesh_vertices[i]->point());
       }
       else {
@@ -602,7 +608,7 @@ void GFace::computeMeanPlane()
 void GFace::computeMeanPlane(const std::vector<MVertex *> &points)
 {
   std::vector<SPoint3> pts;
-  for(unsigned int i = 0; i < points.size(); i++)
+  for(std::size_t i = 0; i < points.size(); i++)
     pts.push_back(SPoint3(points[i]->x(), points[i]->y(), points[i]->z()));
   computeMeanPlane(pts);
 }
@@ -767,7 +773,7 @@ void GFace::computeMeshSizeFieldAccuracy(double &avg, double &max_e,
 {
 #if defined(HAVE_MESH)
   std::set<MEdge, Less_Edge> es;
-  for(unsigned int i = 0; i < getNumMeshElements(); i++) {
+  for(std::size_t i = 0; i < getNumMeshElements(); i++) {
     MElement *e = getMeshElement(i);
     for(int j = 0; j < e->getNumEdges(); j++) es.insert(e->getEdge(j));
   }
@@ -1351,11 +1357,11 @@ bool GFace::fillVertexArray(bool force)
   if(stl_triangles.empty()) return false;
 
   va_geom_triangles = new VertexArray(3, stl_triangles.size() / 3);
-  unsigned int c = CTX::instance()->color.geom.surface;
+  unsigned int c = useColor() ? getColor() : CTX::instance()->color.geom.surface;
   unsigned int col[4] = {c, c, c, c};
   if(stl_vertices_xyz.size() &&
      (stl_vertices_xyz.size() == stl_normals.size())) {
-    for(unsigned int i = 0; i < stl_triangles.size(); i += 3) {
+    for(std::size_t i = 0; i < stl_triangles.size(); i += 3) {
       SPoint3 &p1(stl_vertices_xyz[stl_triangles[i]]);
       SPoint3 &p2(stl_vertices_xyz[stl_triangles[i + 1]]);
       SPoint3 &p3(stl_vertices_xyz[stl_triangles[i + 2]]);
@@ -1369,7 +1375,7 @@ bool GFace::fillVertexArray(bool force)
     }
   }
   else if(stl_vertices_uv.size()) {
-    for(unsigned int i = 0; i < stl_triangles.size(); i += 3) {
+    for(std::size_t i = 0; i < stl_triangles.size(); i += 3) {
       SPoint2 &p1(stl_vertices_uv[stl_triangles[i]]);
       SPoint2 &p2(stl_vertices_uv[stl_triangles[i + 1]]);
       SPoint2 &p3(stl_vertices_uv[stl_triangles[i + 2]]);
@@ -1412,7 +1418,7 @@ bool GFace::fillPointCloud(double maxDist, std::vector<SPoint3> *points,
   if(!points) return false;
 
   if(buildSTLTriangulation() && stl_vertices_uv.size()) {
-    for(unsigned int i = 0; i < stl_triangles.size(); i += 3) {
+    for(std::size_t i = 0; i < stl_triangles.size(); i += 3) {
       SPoint2 &p0(stl_vertices_uv[stl_triangles[i]]);
       SPoint2 &p1(stl_vertices_uv[stl_triangles[i + 1]]);
       SPoint2 &p2(stl_vertices_uv[stl_triangles[i + 2]]);
@@ -1462,13 +1468,13 @@ static void meshCompound(GFace *gf, bool verbose)
   std::vector<GFace *> triangles_tag;
   std::vector<SPoint2> triangles_uv;
 
-  for(unsigned int i = 0; i < gf->_compound.size(); i++) {
+  for(std::size_t i = 0; i < gf->_compound.size(); i++) {
     GFace *c = (GFace *)gf->_compound[i];
     df->triangles.insert(df->triangles.end(), c->triangles.begin(),
                          c->triangles.end());
     df->mesh_vertices.insert(df->mesh_vertices.end(), c->mesh_vertices.begin(),
                              c->mesh_vertices.end());
-    for(unsigned int j = 0; j < c->triangles.size(); j++) {
+    for(std::size_t j = 0; j < c->triangles.size(); j++) {
       triangles_tag.push_back(c);
       for(int k = 0; k < 3; k++) {
         SPoint2 param;
@@ -1483,7 +1489,7 @@ static void meshCompound(GFace *gf, bool verbose)
   df->createGeometry();
   df->mesh(verbose);
 
-  for(GFace::size_type i = 0; i < df->mesh_vertices.size(); i++) {
+  for(std::size_t i = 0; i < df->mesh_vertices.size(); i++) {
     double u, v;
     df->mesh_vertices[i]->getParameter(0, u);
     df->mesh_vertices[i]->getParameter(1, v);
@@ -1511,7 +1517,7 @@ static void meshCompound(GFace *gf, bool verbose)
     }
   }
 
-  for(GFace::size_type i = 0; i < df->triangles.size(); i++) {
+  for(std::size_t i = 0; i < df->triangles.size(); i++) {
     MTriangle *t = df->triangles[i];
     if(t->getVertex(0)->onWhat()->dim() == 2)
       ((GFace *)t->getVertex(0)->onWhat())->triangles.push_back(t);
@@ -1543,7 +1549,7 @@ void GFace::mesh(bool verbose)
   if(_compound.size()) { // Some faces are meshed together
     if(_compound[0] == this) { // I'm the one that makes the compound job
       bool ok = true;
-      for(unsigned int i = 0; i < _compound.size(); i++) {
+      for(std::size_t i = 0; i < _compound.size(); i++) {
         GFace *gf = (GFace *)_compound[i];
         ok &= (gf->meshStatistics.status == GFace::DONE);
       }
@@ -1574,7 +1580,7 @@ void GFace::moveToValidRange(SPoint2 &pt) const
 
 void GFace::relocateMeshVertices()
 {
-  for(unsigned int i = 0; i < mesh_vertices.size(); i++) {
+  for(std::size_t i = 0; i < mesh_vertices.size(); i++) {
     MVertex *v = mesh_vertices[i];
     double u0 = 0., u1 = 0.;
     if(v->getParameter(0, u0) && v->getParameter(1, u1)) {
@@ -1591,7 +1597,7 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
   std::vector<GEdge *>::const_iterator eIter;
   std::list<GVertex *>::iterator vIter;
 
-  Msg::Info("Setting mesh master using transformation ");
+  Msg::Info("Setting mesh master using transformation");
 
   // list all vertices and construct vertex to edge correspondence for local
   // edge
@@ -1602,17 +1608,21 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
   for(eIter = l_edges.begin(); eIter != l_edges.end(); ++eIter) {
     GVertex *v0 = (*eIter)->getBeginVertex();
     GVertex *v1 = (*eIter)->getEndVertex();
-    l_vertices.insert(v0);
-    l_vertices.insert(v1);
-    l_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    if(v0 && v1){
+      l_vertices.insert(v0);
+      l_vertices.insert(v1);
+      l_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    }
   }
 
   for(eIter = embedded_edges.begin(); eIter != embedded_edges.end(); ++eIter) {
     GVertex *v0 = (*eIter)->getBeginVertex();
     GVertex *v1 = (*eIter)->getEndVertex();
-    l_vertices.insert(v0);
-    l_vertices.insert(v1);
-    l_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    if(v0 && v1){
+      l_vertices.insert(v0);
+      l_vertices.insert(v1);
+      l_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    }
   }
 
   l_vertices.insert(embedded_vertices.begin(), embedded_vertices.end());
@@ -1625,9 +1635,11 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
   for(eIter = m_edges.begin(); eIter != m_edges.end(); ++eIter) {
     GVertex *v0 = (*eIter)->getBeginVertex();
     GVertex *v1 = (*eIter)->getEndVertex();
-    m_vertices.insert(v0);
-    m_vertices.insert(v1);
-    m_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    if(v0 && v1){
+      m_vertices.insert(v0);
+      m_vertices.insert(v1);
+      m_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    }
   }
 
   std::vector<GEdge *> const &m_embedded_edges = master->embeddedEdges();
@@ -1636,12 +1648,14 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
       eIter++) {
     GVertex *v0 = (*eIter)->getBeginVertex();
     GVertex *v1 = (*eIter)->getEndVertex();
-    m_vertices.insert(v0);
-    m_vertices.insert(v1);
-    m_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    if(v0 && v1){
+      m_vertices.insert(v0);
+      m_vertices.insert(v1);
+      m_vtxToEdge[std::make_pair(v0, v1)] = (*eIter);
+    }
   }
 
-  std::set<GVertex *> m_embedded_vertices = master->embeddedVertices();
+  std::set<GVertex *, GEntityLessThan> m_embedded_vertices = master->embeddedVertices();
   m_vertices.insert(m_embedded_vertices.begin(), m_embedded_vertices.end());
 
   // check topological correspondence
@@ -1852,13 +1866,16 @@ void GFace::setMeshMaster(GFace *master, const std::map<int, int> &edgeCopies)
     // master edge
     GEdge *me = master->model()->getEdgeByTag(abs(source_e));
 
-    if(source_e * sign > 0) {
-      vs2vt[me->getBeginVertex()] = le->getBeginVertex();
-      vs2vt[me->getEndVertex()] = le->getEndVertex();
-    }
-    else {
-      vs2vt[me->getBeginVertex()] = le->getEndVertex();
-      vs2vt[me->getEndVertex()] = le->getBeginVertex();
+    if(le->getBeginVertex() && le->getEndVertex() &&
+       me->getBeginVertex() && me->getEndVertex()){
+      if(source_e * sign > 0) {
+        vs2vt[me->getBeginVertex()] = le->getBeginVertex();
+        vs2vt[me->getEndVertex()] = le->getEndVertex();
+      }
+      else {
+        vs2vt[me->getBeginVertex()] = le->getEndVertex();
+        vs2vt[me->getEndVertex()] = le->getBeginVertex();
+      }
     }
   }
 
@@ -2029,19 +2046,19 @@ void GFace::removeElement(int type, MElement *e)
   }
 }
 
-bool GFace::reorder(const int elementType, const std::vector<int> &ordering)
+bool GFace::reorder(const int elementType, const std::vector<std::size_t> &ordering)
 {
   if(triangles.size() != 0) {
     if(triangles.front()->getTypeForMSH() == elementType) {
       if(ordering.size() != triangles.size()) return false;
 
-      for(std::vector<int>::const_iterator it = ordering.begin();
+      for(std::vector<std::size_t>::const_iterator it = ordering.begin();
           it != ordering.end(); ++it) {
-        if(*it < 0 || *it >= static_cast<int>(triangles.size())) return false;
+        if(*it >= triangles.size()) return false;
       }
 
       std::vector<MTriangle *> newTrianglesOrder(triangles.size());
-      for(unsigned int i = 0; i < ordering.size(); i++) {
+      for(std::size_t i = 0; i < ordering.size(); i++) {
         newTrianglesOrder[i] = triangles[ordering[i]];
       }
 #if __cplusplus >= 201103L
@@ -2058,13 +2075,13 @@ bool GFace::reorder(const int elementType, const std::vector<int> &ordering)
     if(quadrangles.front()->getTypeForMSH() == elementType) {
       if(ordering.size() != quadrangles.size()) return false;
 
-      for(std::vector<int>::const_iterator it = ordering.begin();
+      for(std::vector<std::size_t>::const_iterator it = ordering.begin();
           it != ordering.end(); ++it) {
-        if(*it < 0 || *it >= static_cast<int>(quadrangles.size())) return false;
+        if(*it >= quadrangles.size()) return false;
       }
 
       std::vector<MQuadrangle *> newQuadranglesOrder(quadrangles.size());
-      for(unsigned int i = 0; i < ordering.size(); i++) {
+      for(std::size_t i = 0; i < ordering.size(); i++) {
         newQuadranglesOrder[i] = quadrangles[ordering[i]];
       }
 #if __cplusplus >= 201103L
@@ -2081,13 +2098,13 @@ bool GFace::reorder(const int elementType, const std::vector<int> &ordering)
     if(polygons.front()->getTypeForMSH() == elementType) {
       if(ordering.size() != polygons.size()) return false;
 
-      for(std::vector<int>::const_iterator it = ordering.begin();
+      for(std::vector<std::size_t>::const_iterator it = ordering.begin();
           it != ordering.end(); ++it) {
-        if(*it < 0 || *it >= static_cast<int>(polygons.size())) return false;
+        if(*it >= polygons.size()) return false;
       }
 
       std::vector<MPolygon *> newPolygonsOrder(polygons.size());
-      for(unsigned int i = 0; i < ordering.size(); i++) {
+      for(std::size_t i = 0; i < ordering.size(); i++) {
         newPolygonsOrder[i] = polygons[ordering[i]];
       }
 #if __cplusplus >= 201103L
