@@ -156,7 +156,7 @@ bool GEO_Internals::addLine(int &tag, const std::vector<int> &pointTags)
   }
   if(tag < 0) tag = getMaxTag(1) + 1;
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < pointTags.size(); i++) {
+  for(std::size_t i = 0; i < pointTags.size(); i++) {
     int t = pointTags[i];
     List_Add(tmp, &t);
   }
@@ -246,7 +246,7 @@ bool GEO_Internals::addSpline(int &tag, const std::vector<int> &pointTags)
   }
   if(tag < 0) tag = getMaxTag(1) + 1;
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < pointTags.size(); i++) {
+  for(std::size_t i = 0; i < pointTags.size(); i++) {
     int t = pointTags[i];
     List_Add(tmp, &t);
   }
@@ -270,7 +270,7 @@ bool GEO_Internals::addBezier(int &tag, const std::vector<int> &pointTags)
     return false;
   }
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < pointTags.size(); i++) {
+  for(std::size_t i = 0; i < pointTags.size(); i++) {
     int t = pointTags[i];
     List_Add(tmp, &t);
   }
@@ -295,7 +295,7 @@ bool GEO_Internals::addBSpline(int &tag, const std::vector<int> &pointTags,
   }
   if(tag < 0) tag = getMaxTag(1) + 1;
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < pointTags.size(); i++) {
+  for(std::size_t i = 0; i < pointTags.size(); i++) {
     int t = pointTags[i];
     List_Add(tmp, &t);
   }
@@ -306,7 +306,7 @@ bool GEO_Internals::addBSpline(int &tag, const std::vector<int> &pointTags,
   else {
     int order = seqknots.size() - pointTags.size() - 1;
     List_T *knotsList = List_Create(2, 2, sizeof(double));
-    for(unsigned int i = 0; i < seqknots.size(); i++) {
+    for(std::size_t i = 0; i < seqknots.size(); i++) {
       double d = seqknots[i];
       List_Add(knotsList, &d);
     }
@@ -327,7 +327,7 @@ bool GEO_Internals::addLineLoop(int &tag, const std::vector<int> &curveTags)
   }
   if(tag < 0) tag = getMaxTag(-1) + 1;
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < curveTags.size(); i++) {
+  for(std::size_t i = 0; i < curveTags.size(); i++) {
     int t = curveTags[i];
     List_Add(tmp, &t);
   }
@@ -351,7 +351,7 @@ bool GEO_Internals::addPlaneSurface(int &tag, const std::vector<int> &wireTags)
     return false;
   }
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < wireTags.size(); i++) {
+  for(std::size_t i = 0; i < wireTags.size(); i++) {
     int t = wireTags[i];
     List_Add(tmp, &t);
   }
@@ -407,7 +407,7 @@ bool GEO_Internals::addSurfaceFilling(int &tag,
     return false;
   }
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < wireTags.size(); i++) {
+  for(std::size_t i = 0; i < wireTags.size(); i++) {
     int t = wireTags[i];
     List_Add(tmp, &t);
   }
@@ -436,7 +436,7 @@ bool GEO_Internals::addSurfaceLoop(int &tag,
   if(tag < 0) tag = getMaxTag(-2) + 1;
 
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < surfaceTags.size(); i++) {
+  for(std::size_t i = 0; i < surfaceTags.size(); i++) {
     int t = surfaceTags[i];
     List_Add(tmp, &t);
   }
@@ -456,7 +456,7 @@ bool GEO_Internals::addVolume(int &tag, const std::vector<int> &shellTags)
   if(tag < 0) tag = getMaxTag(3) + 1;
 
   List_T *tmp = List_Create(2, 2, sizeof(int));
-  for(unsigned int i = 0; i < shellTags.size(); i++) {
+  for(std::size_t i = 0; i < shellTags.size(); i++) {
     int t = shellTags[i];
     List_Add(tmp, &t);
   }
@@ -479,7 +479,7 @@ bool GEO_Internals::_extrude(int mode,
   List_T *in = List_Create(inDimTags.size() + 1, 10, sizeof(Shape));
   List_T *out = List_Create(3 * inDimTags.size() + 1, 10, sizeof(Shape));
 
-  for(unsigned int i = 0; i < inDimTags.size(); i++) {
+  for(std::size_t i = 0; i < inDimTags.size(); i++) {
     int dim = inDimTags[i].first;
     int tag = inDimTags[i].second;
     Shape s;
@@ -564,7 +564,7 @@ bool GEO_Internals::_transform(int mode,
                                double c, double d)
 {
   List_T *list = List_Create(dimTags.size() + 1, 10, sizeof(Shape));
-  for(unsigned int i = 0; i < dimTags.size(); i++) {
+  for(std::size_t i = 0; i < dimTags.size(); i++) {
     int dim = dimTags[i].first;
     int tag = dimTags[i].second;
     Shape s;
@@ -615,7 +615,7 @@ bool GEO_Internals::splitCurve(int tag, const std::vector<int> &pointTags,
                                std::vector<int> &curveTags)
 {
   List_T *tmp = List_Create(10, 10, sizeof(int));
-  for(unsigned int i = 0; i < pointTags.size(); i++) {
+  for(std::size_t i = 0; i < pointTags.size(); i++) {
     int t = pointTags[i];
     List_Add(tmp, &t);
   }
@@ -638,7 +638,7 @@ bool GEO_Internals::intersectCurvesWithSurface(
 {
   List_T *curves = List_Create(10, 10, sizeof(double));
   List_T *shapes = List_Create(10, 10, sizeof(Shape));
-  for(unsigned int i = 0; i < curveTags.size(); i++) {
+  for(std::size_t i = 0; i < curveTags.size(); i++) {
     double d = curveTags[i];
     List_Add(curves, &d);
   }
@@ -662,7 +662,7 @@ bool GEO_Internals::copy(const std::vector<std::pair<int, int> > &inDimTags,
                          std::vector<std::pair<int, int> > &outDimTags)
 {
   bool ret = true;
-  for(unsigned int i = 0; i < inDimTags.size(); i++) {
+  for(std::size_t i = 0; i < inDimTags.size(); i++) {
     int dim = inDimTags[i].first;
     int tag = inDimTags[i].second;
     if(dim == 0) {
@@ -732,7 +732,7 @@ bool GEO_Internals::remove(int dim, int tag, bool recursive)
 bool GEO_Internals::remove(const std::vector<std::pair<int, int> > &dimTags,
                            bool recursive)
 {
-  for(unsigned int i = 0; i < dimTags.size(); i++)
+  for(std::size_t i = 0; i < dimTags.size(); i++)
     remove(dimTags[i].first, dimTags[i].second, recursive);
   return true;
 }
@@ -781,7 +781,7 @@ bool GEO_Internals::modifyPhysicalGroup(int dim, int tag, int op,
   }
   else if(op == 0) {
     List_T *tmp = List_Create(10, 10, sizeof(int));
-    for(unsigned int i = 0; i < tags.size(); i++) {
+    for(std::size_t i = 0; i < tags.size(); i++) {
       int t = tags[i];
       List_Add(tmp, &t);
     }
@@ -790,13 +790,13 @@ bool GEO_Internals::modifyPhysicalGroup(int dim, int tag, int op,
     List_Add(PhysicalGroups, &p);
   }
   else if(op == 1) {
-    for(unsigned int i = 0; i < tags.size(); i++) {
+    for(std::size_t i = 0; i < tags.size(); i++) {
       int t = tags[i];
       List_Add(p->Entities, &t);
     }
   }
   else if(op == 2) {
-    for(unsigned int i = 0; i < tags.size(); i++) {
+    for(std::size_t i = 0; i < tags.size(); i++) {
       int t = tags[i];
       List_Suppress(p->Entities, &t, fcmp_int);
     }
@@ -833,7 +833,7 @@ bool GEO_Internals::mergeVertices(const std::vector<int> &tags)
   }
 
   double x = target->Pos.X, y = target->Pos.Y, z = target->Pos.Z;
-  for(unsigned int i = 1; i < tags.size(); i++) {
+  for(std::size_t i = 1; i < tags.size(); i++) {
     Vertex *source = FindPoint(tags[i]);
     if(!source) {
       Msg::Error("Could not find GEO point with tag %d", tags[i]);
@@ -925,7 +925,7 @@ void GEO_Internals::setTransfiniteSurface(int tag, int arrangement,
       List_Reset(s->TrsfPoints);
       if(cornerTags.empty() || cornerTags.size() == 3 ||
          cornerTags.size() == 4) {
-        for(unsigned int j = 0; j < cornerTags.size(); j++) {
+        for(std::size_t j = 0; j < cornerTags.size(); j++) {
           Vertex *v = FindPoint(std::abs(cornerTags[j]));
           if(v)
             List_Add(s->TrsfPoints, &v);
@@ -961,7 +961,7 @@ void GEO_Internals::setTransfiniteVolume(int tag,
       List_Reset(v->TrsfPoints);
       if(cornerTags.empty() || cornerTags.size() == 6 ||
          cornerTags.size() == 8) {
-        for(unsigned int i = 0; i < cornerTags.size(); i++) {
+        for(std::size_t i = 0; i < cornerTags.size(); i++) {
           Vertex *vert = FindPoint(std::abs(cornerTags[i]));
           if(vert)
             List_Add(v->TrsfPoints, &vert);
@@ -1267,7 +1267,7 @@ void GEO_Internals::synchronize(GModel *model)
     int dim = it->first;
     std::vector<int> compound = it->second;
     std::vector<GEntity *> ents;
-    for(unsigned int i = 0; i < compound.size(); i++) {
+    for(std::size_t i = 0; i < compound.size(); i++) {
       int tag = compound[i];
       GEntity *ent = NULL;
       switch(dim) {
@@ -1278,7 +1278,7 @@ void GEO_Internals::synchronize(GModel *model)
       }
       if(ent) ents.push_back(ent);
     }
-    for(unsigned int i = 0; i < ents.size(); i++) {
+    for(std::size_t i = 0; i < ents.size(); i++) {
       ents[i]->_compound = ents;
     }
   }
@@ -1437,7 +1437,7 @@ public:
       fprintf(geo, "(\"%s\") = {", newName.c_str());
     else
       fprintf(geo, "(%d) = {", g.first);
-    for(unsigned int i = 0; i < g.second.size(); i++) {
+    for(std::size_t i = 0; i < g.second.size(); i++) {
       if(i) fprintf(geo, ", ");
       fprintf(geo, "%d", g.second[i]->tag());
     }
@@ -1526,7 +1526,7 @@ int GModel::writeGEO(const std::string &name, bool printLabels,
   for(std::map<std::string, gmsh_yysymbol>::iterator it =
         gmsh_yysymbols.begin();
       it != gmsh_yysymbols.end(); ++it)
-    for(unsigned int i = 0; i < it->second.value.size(); i++)
+    for(std::size_t i = 0; i < it->second.value.size(); i++)
       labels[(int)it->second.value[i]] = it->first;
 #endif
 
@@ -1535,7 +1535,7 @@ int GModel::writeGEO(const std::string &name, bool printLabels,
   for(int i = 0; i < 4; i++)
     std::for_each(
       groups[i].begin(), groups[i].end(),
-      writePhysicalGroupGEO(fp, i, printLabels, labels, physicalNames));
+      writePhysicalGroupGEO(fp, i, printLabels, labels, _physicalNames));
 
 #if defined(HAVE_MESH)
   std::for_each(getFields()->begin(), getFields()->end(), writeFieldGEO(fp));
@@ -1575,11 +1575,11 @@ int GModel::exportDiscreteGEOInternals()
       for(int i = 0; i < List_Nbr(points); i++) {
         Vertex *v;
         List_Read(points, i, &v);
-        if(v->Num == gvb->tag()) {
+        if(gvb && gvb->tag() == v->Num) {
           List_Add(c->Control_Points, &v);
           c->beg = v;
         }
-        if(v->Num == gve->tag()) {
+        if(gve && gve->tag() == v->Num) {
           List_Add(c->Control_Points, &v);
           c->end = v;
         }
