@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GModel.h"
 #include "OS.h"
@@ -25,7 +25,7 @@ static std::string physicalName(GModel *m, int dim, int num)
             num);
     name = tmp;
   }
-  for(unsigned int i = 0; i < name.size(); i++)
+  for(std::size_t i = 0; i < name.size(); i++)
     if(name[i] == ' ') name[i] = '_';
   return name;
 }
@@ -43,7 +43,7 @@ static void writeElementsKEY(FILE *fp, GEntity *ge, std::vector<T *> &elements,
       fprintf(fp, "*ELEMENT%s\n$#SET_ELEMENT=%s%d\n", typ,
               physicalName(ge->model(), ge->dim(), ge->tag()).c_str(),
               ge->tag());
-      for(unsigned int i = 0; i < elements.size(); i++)
+      for(std::size_t i = 0; i < elements.size(); i++)
         elements[i]->writeKEY(fp, pid, elements[i]->getNum());
     }
   }
@@ -68,24 +68,24 @@ int GModel::writeKEY(const std::string &name, int saveAll,
   fprintf(fp, " %s\n", name.c_str());
 
   fprintf(fp, "*NODE\n");
-  for(unsigned int i = 0; i < entities.size(); i++)
-    for(unsigned int j = 0; j < entities[i]->mesh_vertices.size(); j++)
+  for(std::size_t i = 0; i < entities.size(); i++)
+    for(std::size_t j = 0; j < entities[i]->mesh_vertices.size(); j++)
       entities[i]->mesh_vertices[j]->writeKEY(fp, scalingFactor);
 
-  if(!(saveAll & 0x2)) /* save or ignore Vertex, not in GUI */
+  if(!(saveAll & 0x2)) // save or ignore Vertex, not in GUI
     for(viter it = firstVertex(); it != lastVertex(); ++it) {
       writeElementsKEY(fp, *it, (*it)->points, saveAll & 0x1);
     }
-  if(!(saveAll & 0x8)) /* save or ignore line */
+  if(!(saveAll & 0x8)) // save or ignore line
     for(eiter it = firstEdge(); it != lastEdge(); ++it) {
       writeElementsKEY(fp, *it, (*it)->lines, saveAll & 0x4);
     }
-  if(!(saveAll & 0x20)) /* save or ignore surface */
+  if(!(saveAll & 0x20)) // save or ignore surface
     for(fiter it = firstFace(); it != lastFace(); ++it) {
       writeElementsKEY(fp, *it, (*it)->triangles, saveAll & 0x10);
       writeElementsKEY(fp, *it, (*it)->quadrangles, saveAll & 0x10);
     }
-  if(!(saveAll & 0x80)) /* save or ignore surface */
+  if(!(saveAll & 0x80)) // save or ignore surface
     for(riter it = firstRegion(); it != lastRegion(); ++it) {
       writeElementsKEY(fp, *it, (*it)->tetrahedra, saveAll & 0x40);
       writeElementsKEY(fp, *it, (*it)->hexahedra, saveAll & 0x40);
@@ -100,14 +100,14 @@ int GModel::writeKEY(const std::string &name, int saveAll,
   // save elements sets for each physical group
   if(saveGroupsOfNodes & 0x2) {
     for(int dim = 0; dim <= 3; dim++) {
-      if(saveAll & (0x2 << (2 * dim))) continue; /* elements are ignored*/
+      if(saveAll & (0x2 << (2 * dim))) continue; // elements are ignored
       for(std::map<int, std::vector<GEntity *> >::iterator it =
             groups[dim].begin();
           it != groups[dim].end(); it++) {
         std::vector<GEntity *> &entities = it->second;
         int n = 0;
-        for(unsigned int i = 0; i < entities.size(); i++) {
-          for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+        for(std::size_t i = 0; i < entities.size(); i++) {
+          for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
             MElement *e = entities[i]->getMeshElement(j);
             if(!n) {
               const char *str = (e->getDim() == 3) ?
@@ -119,9 +119,9 @@ int GModel::writeKEY(const std::string &name, int saveAll,
                       physicalName(this, dim, it->first).c_str(), ++setid);
             }
             if(!(n % 8))
-              fprintf(fp, "\n%d", e->getNum());
+              fprintf(fp, "\n%lu", e->getNum());
             else
-              fprintf(fp, ", %d", e->getNum());
+              fprintf(fp, ", %lu", e->getNum());
             n++;
           }
         }
@@ -138,8 +138,8 @@ int GModel::writeKEY(const std::string &name, int saveAll,
           it != groups[dim].end(); it++) {
         std::set<MVertex *> nodes;
         std::vector<GEntity *> &entities = it->second;
-        for(unsigned int i = 0; i < entities.size(); i++) {
-          for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+        for(std::size_t i = 0; i < entities.size(); i++) {
+          for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
             MElement *e = entities[i]->getMeshElement(j);
             for(std::size_t k = 0; k < e->getNumVertices(); k++)
               nodes.insert(e->getVertex(k));
@@ -151,9 +151,9 @@ int GModel::writeKEY(const std::string &name, int saveAll,
         for(std::set<MVertex *>::iterator it2 = nodes.begin();
             it2 != nodes.end(); it2++) {
           if(!(n % 8))
-            fprintf(fp, "\n%d", (*it2)->getIndex());
+            fprintf(fp, "\n%ld", (*it2)->getIndex());
           else
-            fprintf(fp, ", %d", (*it2)->getIndex());
+            fprintf(fp, ", %ld", (*it2)->getIndex());
           n++;
         }
         if(n) fprintf(fp, "\n");
