@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <stdlib.h>
 #include "GModel.h"
@@ -23,7 +23,7 @@
 gmshFace::gmshFace(GModel *m, Surface *face) : GFace(m, face->Num)
 {
   resetNativePtr(face);
-  resetMeshAttributes();
+  gmshFace::resetMeshAttributes();
 }
 
 // a face is degenerate if
@@ -82,7 +82,7 @@ void gmshFace::resetNativePtr(Surface *face)
   l_wire.reserve(eds.size());
 
   GVertex *first = 0;
-  for(unsigned int i = 0; i < eds.size(); i++) {
+  for(std::size_t i = 0; i < eds.size(); i++) {
     GEdge *e = eds[i];
     int num = nums[i];
     GVertex *start = (num > 0) ? e->getBeginVertex() : e->getEndVertex();
@@ -380,7 +380,7 @@ bool gmshFace::buildSTLTriangulation(bool force)
 
   std::map<MVertex *, int> _v;
   int COUNT = 0;
-  for(unsigned int j = 0; j < triangles.size(); j++) {
+  for(std::size_t j = 0; j < triangles.size(); j++) {
     for(int i = 0; i < 3; i++) {
       MVertex *v = triangles[j]->getVertex(i);
       std::map<MVertex *, int>::iterator it = _v.find(v);
