@@ -1,13 +1,13 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributor(s):
 //   Gaetan Bricteux
 
-#ifndef _GMSH_LEVELSET_H_
-#define _GMSH_LEVELSET_H_
+#ifndef GMSH_LEVELSET_H
+#define GMSH_LEVELSET_H
 
 #include <string>
 #include <cmath>
