@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <set>
 #include "GModel.h"
@@ -21,10 +21,15 @@ static void extrudeMesh(GVertex *from, GEdge *to)
       if(j != ep->mesh.NbLayer - 1 || k != ep->mesh.NbElmLayer[j] - 1) {
         Range<double> r = to->parBounds(0);
         double t = r.low() + ep->u(j, k + 1) * (r.high() - r.low());
-        to->mesh_vertices.push_back(new MEdgeVertex(x, y, z, to, t));
+        MEdgeVertex *newv = new MEdgeVertex(x, y, z, to, t);
+        to->mesh_vertices.push_back(newv);
       }
     }
   }
+  to->getEndVertex()->correspondingVertices[to->getEndVertex()->mesh_vertices[0]] = v;
+  std::vector<double> tfo;
+  ep->GetAffineTransform(tfo);
+  to->getEndVertex()->GEntity::setMeshMaster(from, tfo, false);
 }
 
 static void copyMesh(GEdge *from, GEdge *to)
@@ -37,7 +42,7 @@ static void copyMesh(GEdge *from, GEdge *to)
   double u_min = u_bounds.low();
   double u_max = u_bounds.high();
 
-  for(unsigned int i = 0; i < from->mesh_vertices.size(); i++) {
+  for(std::size_t i = 0; i < from->mesh_vertices.size(); i++) {
     int index = (direction < 0) ? (from->mesh_vertices.size() - 1 - i) : i;
     MVertex *v = from->mesh_vertices[index];
     double x = v->x(), y = v->y(), z = v->z();
@@ -46,8 +51,13 @@ static void copyMesh(GEdge *from, GEdge *to)
     double u;
     v->getParameter(0, u);
     double newu = (direction > 0) ? u : (u_max - u + u_min);
-    to->mesh_vertices.push_back(new MEdgeVertex(x, y, z, to, newu));
+    MEdgeVertex *newv = new MEdgeVertex(x, y, z, to, newu);
+    to->mesh_vertices.push_back(newv);
+    to->correspondingVertices[newv] = v;
   }
+  std::vector<double> tfo;
+  ep->GetAffineTransform(tfo);
+  to->GEntity::setMeshMaster(from, tfo, false);
 }
 
 int MeshExtrudedCurve(GEdge *ge)
@@ -56,6 +66,11 @@ int MeshExtrudedCurve(GEdge *ge)
 
   if(!ep || !ep->mesh.ExtrudeMesh) return 0;
 
+  if(!ge->getBeginVertex() || !ge->getEndVertex()){
+    Msg::Error("Cannot extrude curve %d with no begin or end point", ge->tag());
+    return 0;
+  }
+
   Msg::Info("Meshing curve %d (extruded)", ge->tag());
 
   if(ep->geo.Mode == EXTRUDED_ENTITY) {
@@ -78,12 +93,13 @@ int MeshExtrudedCurve(GEdge *ge)
   }
 
   // create elements
-  for(unsigned int i = 0; i < ge->mesh_vertices.size() + 1; i++) {
-    MVertex *v0 = (i == 0) ? ge->getBeginVertex()->mesh_vertices[0] :
-                             ge->mesh_vertices[i - 1];
+  for(std::size_t i = 0; i < ge->mesh_vertices.size() + 1; i++) {
+    MVertex *v0 = (i == 0) ?
+      ge->getBeginVertex()->mesh_vertices[0] :
+      ge->mesh_vertices[i - 1];
     MVertex *v1 = (i == ge->mesh_vertices.size()) ?
-                    ge->getEndVertex()->mesh_vertices[0] :
-                    ge->mesh_vertices[i];
+      ge->getEndVertex()->mesh_vertices[0] :
+      ge->mesh_vertices[i];
     MLine *newElem = new MLine(v0, v1);
     ge->lines.push_back(newElem);
   }
