@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <algorithm>
 #include <math.h>
@@ -15,12 +15,12 @@
 static double _norm(std::vector<double> &x)
 {
   double n = 0.0;
-  for(unsigned int i = 0; i < x.size(); i++) n += x[i] * x[i];
+  for(std::size_t i = 0; i < x.size(); i++) n += x[i] * x[i];
   return sqrt(n);
 }
 static void scale(std::vector<double> &x, double s)
 {
-  for(unsigned int i = 0; i < x.size(); i++) x[i] *= s;
+  for(std::size_t i = 0; i < x.size(); i++) x[i] *= s;
 }
 
 static void gmshLineSearch(void (*func)(std::vector<double> &x, double &Obj,
