@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GmshConfig.h"
 
@@ -140,17 +140,17 @@ PView *GMSH_AnalyseCurvedMeshPlugin::execute(PView *v)
       _computedJac[askedDim - 1] = false;
       _computedIGE[askedDim - 1] = false;
       _computedICN[askedDim - 1] = false;
-      _PViewJac[askedDim - 1] = false;
-      _PViewIGE[askedDim - 1] = false;
-      _PViewICN[askedDim - 1] = false;
+      _pviewJac[askedDim - 1] = false;
+      _pviewIGE[askedDim - 1] = false;
+      _pviewICN[askedDim - 1] = false;
     }
     else {
       _computedJac[1] = _computedJac[2] = false;
       _computedIGE[1] = _computedIGE[2] = false;
       _computedICN[1] = _computedICN[2] = false;
-      _PViewJac[1] = _PViewJac[2] = false;
-      _PViewIGE[1] = _PViewIGE[2] = false;
-      _PViewICN[1] = _PViewICN[2] = false;
+      _pviewJac[1] = _pviewJac[2] = false;
+      _pviewIGE[1] = _pviewIGE[2] = false;
+      _pviewICN[1] = _pviewICN[2] = false;
     }
   }
 
@@ -198,10 +198,10 @@ PView *GMSH_AnalyseCurvedMeshPlugin::execute(PView *v)
   if(drawPView)
     for(int dim = 1; dim <= 3; ++dim) {
       if((askedDim == 4 && dim > 1) || dim == askedDim) {
-        if(!_PViewJac[dim - 1] && computeJac) {
-          _PViewJac[dim - 1] = true;
+        if(!_pviewJac[dim - 1] && computeJac) {
+          _pviewJac[dim - 1] = true;
           std::map<int, std::vector<double> > dataPV;
-          for(unsigned int i = 0; i < _data.size(); ++i) {
+          for(std::size_t i = 0; i < _data.size(); ++i) {
             MElement *const el = _data[i].element();
             if(el->getDim() == dim) {
               double q = 0;
@@ -218,10 +218,10 @@ PView *GMSH_AnalyseCurvedMeshPlugin::execute(PView *v)
             new PView(name.str().c_str(), "ElementData", _m, dataPV);
           }
         }
-        if(!_PViewIGE[dim - 1] && computeIGE) {
-          _PViewIGE[dim - 1] = true;
+        if(!_pviewIGE[dim - 1] && computeIGE) {
+          _pviewIGE[dim - 1] = true;
           std::map<int, std::vector<double> > dataPV;
-          for(unsigned int i = 0; i < _data.size(); ++i) {
+          for(std::size_t i = 0; i < _data.size(); ++i) {
             MElement *const el = _data[i].element();
             if(el->getDim() == dim)
               dataPV[el->getNum()].push_back(_data[i].minS());
@@ -232,10 +232,10 @@ PView *GMSH_AnalyseCurvedMeshPlugin::execute(PView *v)
             new PView(name.str().c_str(), "ElementData", _m, dataPV);
           }
         }
-        if(!_PViewICN[dim - 1] && computeICN) {
-          _PViewICN[dim - 1] = true;
+        if(!_pviewICN[dim - 1] && computeICN) {
+          _pviewICN[dim - 1] = true;
           std::map<int, std::vector<double> > dataPV;
-          for(unsigned int i = 0; i < _data.size(); ++i) {
+          for(std::size_t i = 0; i < _data.size(); ++i) {
             MElement *const el = _data[i].element();
             if(el->getDim() == dim)
               dataPV[el->getNum()].push_back(_data[i].minI());
@@ -278,7 +278,8 @@ void GMSH_AnalyseCurvedMeshPlugin::_computeMinMaxJandValidity(int dim)
     for(GModel::eiter it = _m->firstEdge(); it != _m->lastEdge(); it++)
       entities.insert(*it);
     break;
-  default: Msg::Fatal("This should not happen."); return;
+  default:
+    return;
   }
 
   int cntInverted = 0;
@@ -389,7 +390,7 @@ void GMSH_AnalyseCurvedMeshPlugin::_computeMinIGE(int dim)
 
   MsgProgressStatus progress(_data.size());
 
-  for(unsigned int i = 0; i < _data.size(); ++i) {
+  for(std::size_t i = 0; i < _data.size(); ++i) {
     MElement *const el = _data[i].element();
     if(el->getDim() != dim) continue;
     if(_data[i].minJ() <= 0 && _data[i].maxJ() > 0) {
@@ -410,7 +411,7 @@ void GMSH_AnalyseCurvedMeshPlugin::_computeMinICN(int dim)
 
   MsgProgressStatus progress(_data.size());
 
-  for(unsigned int i = 0; i < _data.size(); ++i) {
+  for(std::size_t i = 0; i < _data.size(); ++i) {
     MElement *const el = _data[i].element();
     if(el->getDim() != dim) continue;
     if(_data[i].minJ() <= 0 && _data[i].maxJ() > 0) {
@@ -433,7 +434,7 @@ int GMSH_AnalyseCurvedMeshPlugin::_hideWithThreshold(int askedDim,
 
   int nHidden = 0;
 
-  for(unsigned int i = 0; i < _data.size(); ++i) {
+  for(std::size_t i = 0; i < _data.size(); ++i) {
     MElement *const el = _data[i].element();
     const int dim = el->getDim();
     if((askedDim == 4 && dim > 1) || dim == askedDim) {
@@ -470,7 +471,7 @@ void GMSH_AnalyseCurvedMeshPlugin::_printStatJacobian()
   supminJ = supratJ = -1e10;
   avgminJ = avgratJ = avgratJc = 0;
 
-  for(unsigned int i = 0; i < _data.size(); ++i) {
+  for(std::size_t i = 0; i < _data.size(); ++i) {
     infminJ = std::min(infminJ, _data[i].minJ());
     supminJ = std::max(supminJ, _data[i].minJ());
     avgminJ += _data[i].minJ();
@@ -513,7 +514,7 @@ void GMSH_AnalyseCurvedMeshPlugin::_printStatIGE()
   double infminS, supminS, avgminS;
   infminS = supminS = avgminS = _data[0].minS();
 
-  for(unsigned int i = 1; i < _data.size(); ++i) {
+  for(std::size_t i = 1; i < _data.size(); ++i) {
     infminS = std::min(infminS, _data[i].minS());
     supminS = std::max(supminS, _data[i].minS());
     avgminS += _data[i].minS();
@@ -533,7 +534,7 @@ void GMSH_AnalyseCurvedMeshPlugin::_printStatICN()
   double infminI, supminI, avgminI;
   infminI = supminI = avgminI = _data[0].minI();
 
-  for(unsigned int i = 1; i < _data.size(); ++i) {
+  for(std::size_t i = 1; i < _data.size(); ++i) {
     infminI = std::min(infminI, _data[i].minI());
     supminI = std::max(supminI, _data[i].minI());
     avgminI += _data[i].minI();
