@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "MeshVolume.h"
 #include "GModel.h"
@@ -66,8 +66,8 @@ void GMSH_MeshVolumePlugin::run(){
   // Iterate on elements and compute the volume //
   ////////////////////////////////////////////////
   double vol = 0;
-  for(unsigned int i = 0; i < entities.size(); i++)
-    for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++)
+  for(std::size_t i = 0; i < entities.size(); i++)
+    for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++)
       vol += entities[i]->getMeshElement(j)->getVolume();
 
   // Display volume as a message //
