@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <math.h>
 #include <list>
@@ -1109,7 +1109,7 @@ template <class T> adaptiveElements<T>::~adaptiveElements()
 template <class T> void adaptiveElements<T>::init(int level)
 {
 #ifdef TIMER
-  double t1 = GetTimeInSeconds();
+  double t1 = TimeOfDay();
 #endif
 
   T::create(level);
@@ -1151,7 +1151,7 @@ template <class T> void adaptiveElements<T>::init(int level)
   if(tmpg) delete tmpg;
 
 #ifdef TIMER
-  adaptiveData::timerInit += GetTimeInSeconds() - t1;
+  adaptiveData::timerInit += TimeOfDay() - t1;
   return;
 #endif
 }
@@ -1159,7 +1159,7 @@ template <class T> void adaptiveElements<T>::init(int level)
 template <> void adaptiveElements<adaptivePyramid>::init(int level)
 {
 #ifdef TIMER
-  double t1 = GetTimeInSeconds();
+  double t1 = TimeOfDay();
 #endif
 
   adaptivePyramid::create(level);
@@ -1205,7 +1205,7 @@ template <> void adaptiveElements<adaptivePyramid>::init(int level)
   if(tmpg) delete tmpg;
 
 #ifdef TIMER
-  adaptiveData::timerInit += GetTimeInSeconds() - t1;
+  adaptiveData::timerInit += TimeOfDay() - t1;
   return;
 #endif
 }
@@ -1233,7 +1233,7 @@ bool adaptiveElements<T>::adapt(double tol, int numComp,
   }
 
 #ifdef TIMER
-  double t1 = GetTimeInSeconds();
+  double t1 = TimeOfDay();
 #endif
 
   fullVector<double> val(numVals), res(numVertices);
@@ -1296,7 +1296,7 @@ bool adaptiveElements<T>::adapt(double tol, int numComp,
   _interpolGeom->mult(xyz, XYZ);
 
 #ifdef TIMER
-  adaptiveData::timerAdapt += GetTimeInSeconds() - t1;
+  adaptiveData::timerAdapt += TimeOfDay() - t1;
   return true;
 #endif
 
@@ -1490,7 +1490,7 @@ void adaptiveElements<T>::addInView(double tol, int step, PViewData *in,
       }
       if(adapt(tol, numComp, coords, values, out->Min, out->Max, plug)){
         *outNb += coords.size() / T::numNodes;
-        for(unsigned int i = 0; i < coords.size() / T::numNodes; i++) {
+        for(std::size_t i = 0; i < coords.size() / T::numNodes; i++) {
           for(int k = 0; k < T::numNodes; ++k)
             outList->push_back(coords[T::numNodes * i + k].c[0]);
           for(int k = 0; k < T::numNodes; ++k)
@@ -2279,7 +2279,7 @@ void adaptiveElements<T>::adaptForVTK(double tol, int numComp,
   }
 
 #ifdef TIMER
-  double t1 = GetTimeInSeconds();
+  double t1 = TimeOfDay();
 #endif
 
   fullVector<double> val(numVals), res(numVertices);
@@ -2339,7 +2339,7 @@ void adaptiveElements<T>::adaptForVTK(double tol, int numComp,
   _interpolGeom->mult(xyz, XYZ);
 
 #ifdef TIMER
-  adaptiveData::timerAdapt += GetTimeInSeconds() - t1;
+  adaptiveData::timerAdapt += TimeOfDay() - t1;
   return;
 #endif
 
@@ -2573,7 +2573,7 @@ void adaptiveElements<T>::addInViewForVTK(int step, PViewData *in,
       myVTKData.vtkLocalCoords.resize(numNodInsert, PCoords(0.0, 0.0, 0.0));
       myVTKData.vtkLocalValues.resize(numNodInsert, PValues(numComp));
 
-      for(unsigned int i = 0; i < coords.size() / T::numNodes; i++) {
+      for(std::size_t i = 0; i < coords.size() / T::numNodes; i++) {
         // Loop over
         //  - all refined elements if refinement level > 0
         //  - single initial element when refinement box is checked for the
