@@ -24,8 +24,8 @@
 //
 // Contributors: Thomas Toulorge, Jonathan Lambrechts
 
-#ifndef _MESHOPT_H_
-#define _MESHOPT_H_
+#ifndef MESH_OPT_H
+#define MESH_OPT_H
 
 #include <iostream>
 #include <fstream>
@@ -33,8 +33,8 @@
 #include <math.h>
 #include <map>
 #include <set>
-#include "MeshOptObjectiveFunction.h"
-#include "MeshOptPatch.h"
+#include "ObjectiveFunction.h"
+#include "Patch.h"
 #include "GmshConfig.h"
 
 #if defined(HAVE_BFGS)
