@@ -24,8 +24,8 @@
 //
 // Contributors: Thomas Toulorge, Jonathan Lambrechts
 
-#ifndef _MESHOPTCOMMON_H_
-#define _MESHOPTCOMMON_H_
+#ifndef MESH_OPT_COMMON_H
+#define MESH_OPT_COMMON_H
 
 #include <vector>
 #include "GmshMessage.h"
