@@ -35,9 +35,6 @@
 #include "GModel.h"
 #include "MTriangle.h"
 #include "MQuadrangle.h"
-#include "MTetrahedron.h"
-#include "MHexahedron.h"
-#include "MPrism.h"
 #include "MLine.h"
 #include "OS.h"
 #include "MeshOpt.h"
@@ -361,7 +358,7 @@ namespace {
                           const elSet &elts, elSet &bndElts,
                           MeshOptParameters &par)
   {
-    for(elSetIter itEl = elts.begin(); itEl != elts.end(); itEl++) {
+    for(elSet::const_iterator itEl = elts.begin(); itEl != elts.end(); itEl++) {
       elElMap::const_iterator itBndEl = el2BndEl.find(*itEl);
       if(itBndEl != el2BndEl.end()) {
         MElement *bndEl = itBndEl->second;
@@ -436,7 +433,7 @@ namespace {
       _patchHistory.push_front(_patchHistory.back());
       _patchHistory.pop_back();
     }
-    sprintf(_patchHistory.front(), objFunctionStr.c_str());
+    sprintf(_patchHistory.front(), "%s", objFunctionStr.c_str());
     mvprintList(9, -8, _patchHistory, 2);
   }
 
@@ -470,6 +467,10 @@ namespace {
                            bndElts[iPatch], par);
     }
     if(par.nCurses) displayResultTable(nbPatchSuccess, toOptimize.size());
+
+#if defined(_OPENMP)
+//#pragma omp parallel for schedule(dynamic)
+#endif
     for(int iPatch = 0; iPatch < toOptimize.size(); ++iPatch) {
       // Initialize optimization and output if asked
       if(par.nCurses) {
@@ -505,25 +506,37 @@ namespace {
 
       // Evaluate mesh and update it if (partial) success
       opt.updateResults();
-      if(newObjFunctionRange.size() == 0) {
-        newObjFunctionRange = opt.objFunction()->minMax();
-        objFunctionNames = opt.objFunction()->names();
-      }
-      else {
-        for(int i = 0; i < newObjFunctionRange.size(); i++) {
-          newObjFunctionRange[i].first = std::min(
-            newObjFunctionRange[i].first, opt.objFunction()->minMax()[i].first);
-          newObjFunctionRange[i].second =
-            std::max(newObjFunctionRange[i].second,
-                     opt.objFunction()->minMax()[i].second);
+
+#if defined(_OPENMP)
+//#pragma omp critical
+#endif
+      {
+        if(newObjFunctionRange.size() == 0) {
+          newObjFunctionRange = opt.objFunction()->minMax();
+          objFunctionNames = opt.objFunction()->names();
+        }
+        else {
+          for(int i = 0; i < newObjFunctionRange.size(); i++) {
+            newObjFunctionRange[i].first =
+              std::min(newObjFunctionRange[i].first,
+                       opt.objFunction()->minMax()[i].first);
+            newObjFunctionRange[i].second =
+              std::max(newObjFunctionRange[i].second,
+                       opt.objFunction()->minMax()[i].second);
+          }
         }
       }
+
       if(success >= 0) opt.patch.updateGEntityPositions();
 
-      //#pragma omp critical
-      par.success = std::min(par.success, success);
+#if defined(_OPENMP)
+//#pragma omp critical
+#endif
+      {
+        par.success = std::min(par.success, success);
+        nbPatchSuccess[success + 1]++;
+      }
 
-      nbPatchSuccess[success + 1]++;
       if(par.nCurses) {
         displayMinMaxVal(nbPatchSuccess, objFunctionNames, newObjFunctionRange);
         displayResultTable(nbPatchSuccess, toOptimize.size());
@@ -531,6 +544,7 @@ namespace {
                                   iPatch, -1);
       }
     }
+
     while(_patchHistory.size() > 0) {
       delete[] _patchHistory.back();
       _patchHistory.pop_back();
@@ -714,7 +728,7 @@ namespace {
 
 #endif
 
-void meshOptimizer(std::vector<GEntity *> &entities, MeshOptParameters &par)
+void MeshOptimizer(std::vector<GEntity *> &entities, MeshOptParameters &par)
 {
 #if defined(HAVE_BFGS)
   if(par.nCurses) mvinit();
